==> kubernetes-model-flowcontrol-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta3/QueuingConfigurationFluentImpl.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta3;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class QueuingConfigurationFluentImpl<A extends QueuingConfigurationFluent<A>> extends BaseFluent<A> implements QueuingConfigurationFluent<A>{
  public QueuingConfigurationFluentImpl() {
  }
  public QueuingConfigurationFluentImpl(QueuingConfiguration instance) {
    this.withHandSize(instance.getHandSize()); 
    this.withQueueLengthLimit(instance.getQueueLengthLimit()); 
    this.withQueues(instance.getQueues()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private Integer handSize;
  private Integer queueLengthLimit;
  private Integer queues;
  private Map<String,Object> additionalProperties;
  public Integer getHandSize() {
    return this.handSize;
  }
  public A withHandSize(Integer handSize) {
    this.handSize=handSize; return (A) this;
  }
  public Boolean hasHandSize() {
    return this.handSize != null;
  }
  public Integer getQueueLengthLimit() {
    return this.queueLengthLimit;
  }
  public A withQueueLengthLimit(Integer queueLengthLimit) {
    this.queueLengthLimit=queueLengthLimit; return (A) this;
  }
  public Boolean hasQueueLengthLimit() {
    return this.queueLengthLimit != null;
  }
  public Integer getQueues() {
    return this.queues;
  }
  public A withQueues(Integer queues) {
    this.queues=queues; return (A) this;
  }
  public Boolean hasQueues() {
    return this.queues != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    QueuingConfigurationFluentImpl that = (QueuingConfigurationFluentImpl) o;
    if (handSize != null ? !handSize.equals(that.handSize) :that.handSize != null) return false;
    if (queueLengthLimit != null ? !queueLengthLimit.equals(that.queueLengthLimit) :that.queueLengthLimit != null) return false;
    if (queues != null ? !queues.equals(that.queues) :that.queues != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(handSize,  queueLengthLimit,  queues,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (handSize != null) { sb.append("handSize:"); sb.append(handSize + ","); }
    if (queueLengthLimit != null) { sb.append("queueLengthLimit:"); sb.append(queueLengthLimit + ","); }
    if (queues != null) { sb.append("queues:"); sb.append(queues + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> kubernetes-model-flowcontrol-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta3/QueuingConfigurationFluentImpl.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta3;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class QueuingConfigurationFluentImpl<A extends QueuingConfigurationFluent<A>> extends BaseFluent<A> implements QueuingConfigurationFluent<A>{
  public QueuingConfigurationFluentImpl() {
  }
  public QueuingConfigurationFluentImpl(QueuingConfiguration instance) {
    if (instance != null) {
      this.withHandSize(instance.getHandSize());
      this.withQueueLengthLimit(instance.getQueueLengthLimit());
      this.withQueues(instance.getQueues());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Integer handSize;
  private Integer queueLengthLimit;
  private Integer queues;
  private Map<String,Object> additionalProperties;
  public Integer getHandSize() {
    return this.handSize;
  }
  public A withHandSize(Integer handSize) {
    this.handSize=handSize; return (A) this;
  }
  public Boolean hasHandSize() {
    return this.handSize != null;
  }
  public Integer getQueueLengthLimit() {
    return this.queueLengthLimit;
  }
  public A withQueueLengthLimit(Integer queueLengthLimit) {
    this.queueLengthLimit=queueLengthLimit; return (A) this;
  }
  public Boolean hasQueueLengthLimit() {
    return this.queueLengthLimit != null;
  }
  public Integer getQueues() {
    return this.queues;
  }
  public A withQueues(Integer queues) {
    this.queues=queues; return (A) this;
  }
  public Boolean hasQueues() {
    return this.queues != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    QueuingConfigurationFluentImpl that = (QueuingConfigurationFluentImpl) o;
    if (!java.util.Objects.equals(handSize, that.handSize)) return false;

    if (!java.util.Objects.equals(queueLengthLimit, that.queueLengthLimit)) return false;

    if (!java.util.Objects.equals(queues, that.queues)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(handSize,  queueLengthLimit,  queues,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (handSize != null) { sb.append("handSize:"); sb.append(handSize + ","); }
    if (queueLengthLimit != null) { sb.append("queueLengthLimit:"); sb.append(queueLengthLimit + ","); }
    if (queues != null) { sb.append("queues:"); sb.append(queues + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
